API Reference
=============

This part of the documentation contains detailed information about various modules and function of this library.

.. autosummary::
    :toctree: _generated
    :recursive:

    simple_openid_connect

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
